@@ -539,8 +539,8 @@ class BackendIPythonNotebook(BackendIPython):
                      u'text/plain': plain_text.text.get_unicode(),
             }, {})
         elif isinstance(rich_output, OutputHtml):
-            return ({u'text/html':  rich_output.html.get(),
-                     u'text/plain': plain_text.text.get(),
+            return ({u'text/html':  rich_output.html.get_unicode(),
+                     u'text/plain': plain_text.text.get_unicode(),
             }, {})
         elif isinstance(rich_output, OutputImagePng):
             return ({u'image/png':  rich_output.png.get(),
@@ -548,7 +548,7 @@ class BackendIPythonNotebook(BackendIPython):
             }, {})
         elif isinstance(rich_output, OutputImageGif):
             return ({u'text/html':  rich_output.html_fragment(),
-                     u'text/plain': plain_text.text.get(),
+                     u'text/plain': plain_text.text.get_unicode(),
             }, {})
         elif isinstance(rich_output, OutputImageJpg):
             return ({u'image/jpeg':  rich_output.jpg.get(),
@@ -604,4 +604,4 @@ class BackendIPythonNotebook(BackendIPython):
 <script>
   if ( !window.THREE ) document.write('{}');
 </script>
-        """.format(CDN_scripts.replace('</script>', r'<\/script>'))
+        """.format(CDN_scripts.replace('</script>', r'<\/script>').replace('\n', ' \\\n'))
